@@ -35,7 +35,8 @@
 #include "config.h"
 #include "CuTest.h"
 
-#include "library.h"
+#include "debug.h"
+#include "message.h"
 
 #include <assert.h>
 #include <string.h>
@@ -1203,7 +1204,7 @@ main (void)
 	int ret;
 
 	putenv ("P11_KIT_STRICT=1");
-	p11_library_init ();
+	p11_debug_init ();
 
 	SUITE_ADD_TEST (suite, test_uri_parse);
 	SUITE_ADD_TEST (suite, test_uri_parse_bad_scheme);
